# My Project

Describe what your package is about

## Package Distribution

### Installation

`pip install my-project`

### Use

`python ./src/main.py`

## Docker Distibution

### Installation

`docker pull docker_user/project_name:latest`

### Use

`docker run -p 5000:5000 project_name`

or for detached mode:

`docker run -d -p 5000:5000 project_name`

